import QtQuick 2.0
import Sailfish.Silica 1.0
import org.nemomobile.configuration 1.0

Page {
    id: page

    ConfigurationGroup {
        id: analogclockSettings
        path: "/jolla-clock/analogclock"
		property bool analogClock: true
		property bool analogClockSeconds: false
		property bool digitalclockSeconds: false
        property int size: 320
		property int clocktopmargin: 130
		property int datetopmargin: 6
        property int face: 1	
        property int hourhandle: 1	
	    property int minutehandle: 1
		property int secondshandle: 1
		property bool digitalclock: false
        property int dclocksize: 100
        property int dclocktopmargin: 130
		property int weathertopmargin: 480
        property bool landscape: false
        property bool background: false
        property int opacity: 50
        property bool weather: false
        property int lockScale: 80
		property int sneakScale: 90		
        property int weekdaysize: 30
        property int shortdatesize: 50	
		property bool alarmIndicators: false
		property bool colored_alarmIndicators: false
		property bool forecast: false
		property bool launch_clock: false
		property bool launch_digital_clock: false
    }

    SilicaFlickable {
        anchors.fill: parent
        contentHeight: content.height
        interactive: contentHeight > height
		
        PullDownMenu {
            MenuItem {
                text: qsTr("Settings for landscape orientation")
                onClicked: pageStack.push(Qt.resolvedUrl("landscape.qml"))
            }
        }
		
        Column {
		    id: content
            width: parent.width
            spacing: Theme.paddingLarge
			
			SectionHeader {
		        text: qsTr("Settings for portrait orientation")
		    }	
			
			ExpandingSection {
                buttonHeight: Theme.itemSizeMedium
                title: qsTr("Analog clock")
				
                content.sourceComponent: Column {
				
				TextSwitch {
					width: parent.width
					text: qsTr("Show analog clock")
					checked: analogclockSettings.analogClock
					onClicked: analogclockSettings.analogClock = checked
				}
					
	                width: parent.width
					
				    SectionHeader {
		                text: qsTr("Choose clock face")
						visible: analogclockSettings.analogClock
		            }
								
		            Row {
		                id: clockfaceRow
		                width: parent.width
						visible: analogclockSettings.analogClock
						
						Rectangle {
						    id: face1
						    color: (analogclockSettings.face == 1) ? Theme.secondaryHighlightColor : "transparent" 
						    width: clockfaceRow.width/4
						    height: clockfaceRow.width/4
							
						    Image {
						        source: "analog_clock_face_1.svg"
						        width: parent.width
						        height: parent.height
						    }
							
		                    MouseArea {
		                        anchors.fill: parent
		                        onClicked: { 
								    analogclockSettings.face = 1
								}
		                    }				
						}	
		
						Rectangle {
						    id: face2
						    color: (analogclockSettings.face == 2) ? Theme.secondaryHighlightColor : "transparent" 
						    width: clockfaceRow.width/4
						    height: clockfaceRow.width/4
							
						    Image {
						        source: "analog_clock_face_2.svg"
						        width: parent.width
						        height: parent.height
						    }
							
		                    MouseArea {
		                        anchors.fill: parent
		                        onClicked: {
								    analogclockSettings.face = 2						
								}
		                    }				
						}
						
						Rectangle {
						    id: face3
						    color: (analogclockSettings.face == 3) ? Theme.secondaryHighlightColor : "transparent" 
						    width: clockfaceRow.width/4
						    height: clockfaceRow.width/4
							
						    Image {
						        source: "analog_clock_face_3.svg"
						        width: parent.width
						        height: parent.height
						    }
							
		                    MouseArea {
		                        anchors.fill: parent
		                        onClicked: { 
								    analogclockSettings.face = 3						
								}
		                    }				
						}
		
						Rectangle {
						    id: face4
						    color: (analogclockSettings.face == 4) ? Theme.secondaryHighlightColor : "transparent" 
						    width: clockfaceRow.width/4
						    height: clockfaceRow.width/4
							
						    Image {
						        source: "analog_clock_face_4.svg"
						        width: parent.width
						        height: parent.height
						    }
							
		                    MouseArea {
		                        anchors.fill: parent
		                        onClicked: {
								    analogclockSettings.face = 4
								}
		                    }				
						}				
					}
					
		            Separator {
		                color: Theme.secondaryHighlightColor
		                width: parent.width
		                anchors.horizontalCenter: parent.horizontalCenter
		                horizontalAlignment: Qt.AlignHCenter
						visible: analogclockSettings.analogClock
		            }
					
				    SectionHeader {
		                text: qsTr("Choose hour handle")
						visible: analogclockSettings.analogClock
		            }
					
		            Row {
		                id: hourhandleRow
		                width: parent.width
						visible: analogclockSettings.analogClock
						
						Rectangle {
						    id: hourhandle1
						    color: (analogclockSettings.hourhandle == 1) ? Theme.secondaryHighlightColor : "transparent" 
						    width: hourhandleRow.width/4
						    height: hourhandleRow.width/4
							
						    Image {
						        source: "analog_hour_handle_1.svg"
						        width: parent.width
						        height: parent.height
						    }
							
		                    MouseArea {
		                        anchors.fill: parent
		                        onClicked: { 
								    analogclockSettings.hourhandle = 1
								}
		                    }				
						}	
		
						Rectangle {
						    id: hourhandle2
						    color: (analogclockSettings.hourhandle == 2) ? Theme.secondaryHighlightColor : "transparent" 
						    width: hourhandleRow.width/4
						    height: hourhandleRow.width/4
							
						    Image {
						        source: "analog_hour_handle_2.svg"
						        width: parent.width
						        height: parent.height
						    }
							
		                    MouseArea {
		                        anchors.fill: parent
		                        onClicked: {
								    analogclockSettings.hourhandle = 2						
								}
		                    }				
						}
						
						Rectangle {
						    id: hourhandle3
						    color: (analogclockSettings.hourhandle == 3) ? Theme.secondaryHighlightColor : "transparent" 
						    width: hourhandleRow.width/4
						    height: hourhandleRow.width/4
							
						    Image {
						        source: "analog_hour_handle_3.svg"
						        width: parent.width
						        height: parent.height
						    }
							
		                    MouseArea {
		                        anchors.fill: parent
		                        onClicked: { 
								    analogclockSettings.hourhandle = 3						
								}
		                    }				
						}
		
						Rectangle {
						    id: hourhandle4
						    color: (analogclockSettings.hourhandle == 4) ? Theme.secondaryHighlightColor : "transparent" 
						    width: hourhandleRow.width/4
						    height: hourhandleRow.width/4
							
						    Image {
						        source: "analog_hour_handle_4.svg"
						        width: parent.width
						        height: parent.height
						    }
							
		                    MouseArea {
		                        anchors.fill: parent
		                        onClicked: {
								    analogclockSettings.hourhandle = 4
								}
		                    }				
						}				
					}
					
		            Separator {
		                color: Theme.secondaryHighlightColor
		                width: parent.width
		                anchors.horizontalCenter: parent.horizontalCenter
		                horizontalAlignment: Qt.AlignHCenter
						visible: analogclockSettings.analogClock
		            }
					
				    SectionHeader {
		                text: qsTr("Choose minute handle")
						visible: analogclockSettings.analogClock
		            }
					
		            Row {
		                id: minutehandleRow
		                width: parent.width
						visible: analogclockSettings.analogClock
						
						Rectangle {
						    id: minutehandle1
						    color: (analogclockSettings.minutehandle == 1) ? Theme.secondaryHighlightColor : "transparent" 
						    width: minutehandleRow.width/4
						    height: minutehandleRow.width/4
							
						    Image {
						        source: "analog_minute_handle_1.svg"
						        width: parent.width
						        height: parent.height
						    }
							
		                    MouseArea {
		                        anchors.fill: parent
		                        onClicked: { 
								    analogclockSettings.minutehandle = 1
								}
		                    }				
						}	
		
						Rectangle {
						    id: minutehandle2
						    color: (analogclockSettings.minutehandle == 2) ? Theme.secondaryHighlightColor : "transparent" 
						    width: minutehandleRow.width/4
						    height: minutehandleRow.width/4
							
						    Image {
						        source: "analog_minute_handle_2.svg"
						        width: parent.width
						        height: parent.height
						    }
							
		                    MouseArea {
		                        anchors.fill: parent
		                        onClicked: {
								    analogclockSettings.minutehandle = 2						
								}
		                    }				
						}
						
						Rectangle {
						    id: minutehandle3
						    color: (analogclockSettings.minutehandle == 3) ? Theme.secondaryHighlightColor : "transparent" 
						    width: minutehandleRow.width/4
						    height: minutehandleRow.width/4
							
						    Image {
						        source: "analog_minute_handle_3.svg"
						        width: parent.width
						        height: parent.height
						    }
							
		                    MouseArea {
		                        anchors.fill: parent
		                        onClicked: { 
								    analogclockSettings.minutehandle = 3						
								}
		                    }				
						}
		
						Rectangle {
						    id: minutehandle4
						    color: (analogclockSettings.minutehandle == 4) ? Theme.secondaryHighlightColor : "transparent" 
						    width: minutehandleRow.width/4
						    height: minutehandleRow.width/4
							
						    Image {
						        source: "analog_minute_handle_4.svg"
						        width: parent.width
						        height: parent.height
						    }
							
		                    MouseArea {
		                        anchors.fill: parent
		                        onClicked: {
								    analogclockSettings.minutehandle = 4
								}
		                    }				
						}				
					}
					
		            Separator {
		                color: Theme.secondaryHighlightColor
		                width: parent.width
		                anchors.horizontalCenter: parent.horizontalCenter
		                horizontalAlignment: Qt.AlignHCenter
						visible: analogclockSettings.analogClock
		            }
					
					TextSwitch {
						width: parent.width
						visible: analogclockSettings.analogClock
						text: qsTr("Enable seconds")
						checked: analogclockSettings.analogClockSeconds
						onClicked: analogclockSettings.analogClockSeconds = checked
					}	
										
				    SectionHeader {
		                text: qsTr("Choose seconds handle")
						visible: analogclockSettings.analogClockSeconds && analogclockSettings.analogClock
		            }
					
		            Row {
		                id: secondshandleRow
		                width: parent.width
						visible: analogclockSettings.analogClockSeconds && analogclockSettings.analogClock
						
						Rectangle {
						    id: secondhandle1
						    color: (analogclockSettings.secondshandle == 1) ? Theme.secondaryHighlightColor : "transparent" 
						    width: secondshandleRow.width/2
						    height: secondshandleRow.width/2
							
						    Image {
						        source: "analog_second_handle_1.svg"
						        width: parent.width
						        height: parent.height
						    }
							
		                    MouseArea {
		                        anchors.fill: parent
		                        onClicked: { 
								    analogclockSettings.secondshandle = 1
								}
		                    }				
						}	
		
						Rectangle {
						    id: secondhandle2
						    color: (analogclockSettings.secondshandle == 2) ? Theme.secondaryHighlightColor : "transparent" 
						    width: secondshandleRow.width/2
						    height: secondshandleRow.width/2
							
						    Image {
						        source: "analog_second_handle_2.svg"
						        width: parent.width
						        height: parent.height
						    }
							
		                    MouseArea {
		                        anchors.fill: parent
		                        onClicked: { 
								    analogclockSettings.secondshandle = 2
								}
		                    }				
						}				
					}
					
		            Separator {
		                color: Theme.secondaryHighlightColor
		                width: parent.width
		                anchors.horizontalCenter: parent.horizontalCenter
		                horizontalAlignment: Qt.AlignHCenter
						visible: analogclockSettings.analogClock
		            }	
					
		            TextSwitch {
						width: parent.width
						visible: analogclockSettings.analogClock
		                text: qsTr("Enable background")
						description: qsTr("Enables colored background. Probably it will be useful with light-ambiences.")
		                checked: analogclockSettings.background
		                onClicked: analogclockSettings.background = checked
		            }
		
					Slider { 			   
		                width: parent.width
						visible: analogclockSettings.background && analogclockSettings.analogClock
		                label: qsTr("Opacity")
		                maximumValue: 90
		                minimumValue: 10
		                stepSize: 1
		                value: analogclockSettings.opacity
		                valueText: value + "%"
		
		                onValueChanged: analogclockSettings.opacity = Math.round(value)
		                onPressAndHold: cancel()
		            }
					
		            TextSwitch {
		                width: parent.width
		                text: qsTr("Enable alarm indicators")
		                checked: analogclockSettings.alarmIndicators
		                onClicked: analogclockSettings.alarmIndicators = checked
		            }
					
		            TextSwitch {
						visible: analogclockSettings.alarmIndicators
						description: qsTr("Enables different colors for alarm indicators like in Clock-app cover.")
		                width: parent.width
		                text: qsTr("Use colored indicators")
		                checked: analogclockSettings.colored_alarmIndicators
		                onClicked: analogclockSettings.colored_alarmIndicators = checked
		            }	
					
		            Separator {
		                color: Theme.secondaryHighlightColor
		                width: parent.width
		                anchors.horizontalCenter: parent.horizontalCenter
		                horizontalAlignment: Qt.AlignHCenter
						visible: analogclockSettings.analogClock
		            }
					
		            TextSwitch {
						description: qsTr("Enables clock launching by clicking on clock-face from lockscreen.")
						visible: analogclockSettings.analogClock
		                width: parent.width
		                text: qsTr("Enable clock-launch from lockscreen")
		                checked: analogclockSettings.launch_clock
		                onClicked: analogclockSettings.launch_clock = checked
		            }					
				}
            }
			
			ExpandingSection {
                buttonHeight: Theme.itemSizeMedium
                title: qsTr("Digital clock")
				
                content.sourceComponent: Column {
	                width: parent.width	
					
		            TextSwitch {
		                width: parent.width
		                text: qsTr("Show digital clock")
		                checked: analogclockSettings.digitalclock
		                onClicked: analogclockSettings.digitalclock = checked
		            }
										
		            TextSwitch {
		                width: parent.width
						visible: analogclockSettings.digitalclock
		                text: qsTr("Enable seconds")
		                checked: analogclockSettings.digitalclockSeconds
		                onClicked: analogclockSettings.digitalclockSeconds = checked
		            }
					
			        TextSwitch {
						description: qsTr("Enables clock launching by clicking on clock from lockscreen.")
						visible: analogclockSettings.digitalclock
		                width: parent.width
		                text: qsTr("Enable clock-launch from lockscreen")
		                checked: analogclockSettings.launch_digital_clock
		                onClicked: analogclockSettings.launch_digital_clock = checked
		            }				
				}
			}
			
			ExpandingSection {
                buttonHeight: Theme.itemSizeMedium
                title: qsTr("Weather-widget")
				
                content.sourceComponent: Column {
	                width: parent.width	
					
		            TextSwitch {
		                width: parent.width
		                text: qsTr("Show weather-widget")
		                checked: analogclockSettings.weather
		                onClicked: analogclockSettings.weather = checked
		            }
			
		            Slider {
		                width: parent.width
						visible: analogclockSettings.weather
		                label: qsTr("Choose lockscreen widget scale")
		                maximumValue: Screen.sizeCategory < Screen.Large ? 150 : 200
		                minimumValue: 50
		                stepSize: 10
		                value: analogclockSettings.lockScale
		                valueText: value + "%"
		
		                onValueChanged: analogclockSettings.lockScale = Math.round(value)
		                onPressAndHold: cancel()
		            }
					
		            Slider {
		                width: parent.width
						visible: analogclockSettings.weather
		                label: qsTr("Choose Sneak Peek widget scale")
		                maximumValue: Screen.sizeCategory < Screen.Large ? 150 : 200
		                minimumValue: 50
		                stepSize: 10
		                value: analogclockSettings.sneakScale
		                valueText: value + "%"
		
		                onValueChanged: analogclockSettings.sneakScale = Math.round(value)
		                onPressAndHold: cancel()
		            }	
					
		            TextSwitch {
		                width: parent.width
						visible: analogclockSettings.weather
		                text: qsTr("Enable 5-days forecast")
						description: qsTr("It will show 5-day weather forecast on your lockscreen, click weather-widget to show or hide forecast.") + " " +
							qsTr("Please, hide forecast before disabling this option.")
		                checked: analogclockSettings.forecast
		                onClicked: analogclockSettings.forecast = checked
		            }					
				}	
			}
			
			ExpandingSection {
                buttonHeight: Theme.itemSizeMedium
                title: qsTr("Clocks and date sizes")
				
                content.sourceComponent: Column {
	                width: parent.width			
			
		            Slider {
		                width: parent.width
		                label: qsTr("Analog clock size")
						visible: analogclockSettings.analogClock
		                maximumValue: Screen.sizeCategory < Screen.Large ? 560 : 1000
		                minimumValue: 200
		                stepSize: 10
		                value: analogclockSettings.size
		                valueText: value + "x" + value + " " + qsTr("px")
		
		                onValueChanged: analogclockSettings.size = Math.round(value)
		                onPressAndHold: cancel()
		            }
					
		            Slider {
		                width: parent.width
						visible: analogclockSettings.digitalclock
		                label: qsTr("Digital clock size")
		                maximumValue: 220
		                minimumValue: 10
		                stepSize: 1
		                value: analogclockSettings.dclocksize
		                valueText: value + " " + qsTr("px")
		
		                onValueChanged: analogclockSettings.dclocksize = Math.round(value)
		                onPressAndHold: cancel()
		            }
					
		            Slider {
		                width: parent.width
		                label: qsTr("Weekday size")
		                maximumValue: Screen.sizeCategory < Screen.Large ? 120 : 200
		                minimumValue: 10
		                stepSize: 1
		                value: analogclockSettings.weekdaysize
		                valueText: value + " " + qsTr("px")
		
		                onValueChanged: analogclockSettings.weekdaysize = Math.round(value)
		                onPressAndHold: cancel()
		            }
					
		            Slider {
		                width: parent.width
		                label: qsTr("Month date size")
		                maximumValue: Screen.sizeCategory < Screen.Large ? 120 : 200
		                minimumValue: 10
		                stepSize: 1
		                value: analogclockSettings.shortdatesize
		                valueText: value + " " + qsTr("px")
		
		                onValueChanged: analogclockSettings.shortdatesize = Math.round(value)
		                onPressAndHold: cancel()
		            }
				}
			}	
						
			ExpandingSection {
                buttonHeight: Theme.itemSizeMedium
                title: qsTr("Margins")
				id: margins
                content.sourceComponent: Column {
	                width: parent.width
					
					Slider {
		                width: parent.width
		                label: qsTr("Analog clock top margin")
						enabled: margins.expanded
		                maximumValue: 800
		                minimumValue: Screen.sizeCategory < Screen.Large ? 0 : -800
		                stepSize: 1
		                value: analogclockSettings.clocktopmargin
		                valueText: value
						visible: analogclockSettings.analogClock
		                onValueChanged: analogclockSettings.clocktopmargin = Math.round(value)
		                onPressAndHold: cancel()
		            }
					
					Slider {
		                width: parent.width
						visible: analogclockSettings.digitalclock
						enabled: margins.expanded
		                label: qsTr("Digital clock top margin")
		                maximumValue: 900
		                minimumValue: Screen.sizeCategory < Screen.Large ? 10 : -800
		                stepSize: 1
		                value: analogclockSettings.dclocktopmargin
		                valueText: value
		
		                onValueChanged: analogclockSettings.dclocktopmargin = Math.round(value)
		                onPressAndHold: cancel()
		            }
					
					Slider {
		                width: parent.width
		                label: qsTr("Date top margin")
						enabled: margins.expanded
		                maximumValue: 800
		                minimumValue: Screen.sizeCategory < Screen.Large ? -100 : -800
		                stepSize: 1
		                value: analogclockSettings.datetopmargin
		                valueText: value
		
		                onValueChanged: analogclockSettings.datetopmargin = Math.round(value)
		                onPressAndHold: cancel()
		            }
					
					Slider {
		                width: parent.width
		                label: qsTr("Weather-widget top margin")
						enabled: margins.expanded
		                maximumValue: 800
		                minimumValue: Screen.sizeCategory < Screen.Large ? -100 : -800
		                stepSize: 1
		                value: analogclockSettings.weathertopmargin
		                valueText: value
						visible: analogclockSettings.weathertopmargin		
		                onValueChanged: analogclockSettings.weathertopmargin = Math.round(value)
		                onPressAndHold: cancel()
		            }					
				}
			}	
									
		    Item {
			    width: 1
                height: Theme.paddingMedium
			}	
			
            Separator {
                color: Theme.secondaryHighlightColor
                width: parent.width
                anchors.horizontalCenter: parent.horizontalCenter
                horizontalAlignment: Qt.AlignHCenter
            }
			
		    Item {
			    width: 1
                height: Theme.paddingMedium
			}
			
            Label {
                width: parent.width
                wrapMode: Text.Wrap
                horizontalAlignment: Text.AlignHCenter
                text: qsTr("Created by Ancelad in 0x7DF")
            }
			
		    Item {
			    width: 1
                height: Theme.paddingMedium
			}	
			
            Label {
                width: parent.width
                wrapMode: Text.Wrap
                horizontalAlignment: Text.AlignHCenter
                text: qsTr("Big thanks to Ruslan Burkhanov for \nSVG-graphics :)")
            }
			
		    Item {
			    width: 1
                height: Theme.paddingMedium
			}	
			
		    Label {
                text: qsTr("Donations are welcome :)")
                width: parent.width
				wrapMode: Text.Wrap
                horizontalAlignment: Text.AlignHCenter
            }

            Button {
                text: qsTr("Donate")
                width: 200
                anchors.horizontalCenter: parent.horizontalCenter
                onClicked: {
                    Qt.openUrlExternally("https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=E33PBZ79WTQJY")
                }
            }			
        }
    }
}
